package com.sun.org.apache.bcel.internal.generic;

import com.sun.org.apache.bcel.internal.classfile.LineNumber;

public class LineNumberGen implements InstructionTargeter, Cloneable
{
    private InstructionHandle ih;
    private int src_line;
    
    public LineNumberGen(InstructionHandle ih, int src_line) {
        this.setInstruction(ih);
        this.setSourceLine(src_line);
    }
    
    @Override
    public boolean containsTarget(InstructionHandle ih) {
        return this.ih == ih;
    }
    
    @Override
    public void updateTarget(InstructionHandle old_ih, InstructionHandle new_ih) {
        if (old_ih != this.ih) {
            throw new ClassGenException("Not targeting " + old_ih + ", but " + this.ih + "}");
        }
        this.setInstruction(new_ih);
        return;
    }
    
    public LineNumber getLineNumber() {
        return new LineNumber(this.ih.getPosition(), this.src_line);
    }
    
    public void setInstruction(InstructionHandle ih) {
        if (ih == null) {
            throw new NullPointerException("InstructionHandle may not be null");
        }
        BranchInstruction.notifyTarget(this.ih, ih, this);
        this.ih = ih;
        return;
    }
    
    public Object clone() {
        try {
            return super.clone();
        }
        catch (CloneNotSupportedException e) {
            throw new Error("Clone Not Supported");
        }
    }
    
    public InstructionHandle getInstruction() {
        return this.ih;
    }
    
    public void setSourceLine(int src_line) {
        this.src_line = src_line;
    }
    
    public int getSourceLine() {
        return this.src_line;
    }
}
